# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['sys_config']

package_data = \
{'': ['*']}

setup_kwargs = {
    'name': 'sys-config',
    'version': '0.2.1',
    'description': 'Awesome `sys-config` is a Python cli/package created with https://github.com/william-cass-wright/cookiecutter-pypackage-slim',
    'long_description': '<div align="center">\n\n# sys-config\n\n[![Build status](https://github.com/william-cass-wright/sys-config/workflows/build/badge.svg?branch=main&event=push)](https://github.com/william-cass-wright/sys-config/actions?query=workflow%3Abuild)\n[![Python Version](https://img.shields.io/pypi/pyversions/sys-config.svg)](https://pypi.org/project/sys-config/)\n[![Dependencies Status](https://img.shields.io/badge/dependencies-up%20to%20date-brightgreen.svg)](https://github.com/william-cass-wright/sys-config/pulls?utf8=%E2%9C%93&q=is%3Apr%20author%3Aapp%2Fdependabot)\n\n[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)\n[![Security: bandit](https://img.shields.io/badge/security-bandit-green.svg)](https://github.com/PyCQA/bandit)\n[![Pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white)](https://github.com/william-cass-wright/sys-config/blob/main/.pre-commit-config.yaml)\n[![Semantic Versions](https://img.shields.io/badge/%20%20%F0%9F%93%A6%F0%9F%9A%80-semantic--versions-e10079.svg)](https://github.com/william-cass-wright/sys-config/releases)\n[![License](https://img.shields.io/github/license/william-cass-wright/sys-config)](https://github.com/william-cass-wright/sys-config/blob/main/LICENSE)\n![Coverage Report](assets/images/coverage.svg)\n\n</div>\n\n`sys-config` is a Python package created with [william-cass-wright/cookiecutter-pypackage-slim](https://github.com/william-cass-wright/cookiecutter-pypackage-slim)... kinda\n\n</div>\n\n**PROJECT DEVELOPMENT NOTES**\n\n## Summary\n\n### how to use\n\n- command line tool (component of `smgmt`)\n    - transfer AWS Secrets to local (or visversa)\n    - crawl `~/.config` & `~` directories for credentials/configs\n        - systematically extract and transform for command line\n- within CLI project (used to implement `mmgmt`)\n    - init new project after binary install\n    - explicitly call config file (endpoint usage pattern)\n    - function dectorator (on top of command/endpoint)\n    - within context???\n- other types of projects???\n\n### value to include in config file?\n\n- pypi tokens\n- api keys\n- dev and prod split\n- app specific references within file system\n\n### components\n\n- file crawler\n- extractor\n- click interface (class inheritance --> factory design pattern?)\n\n## Usage\n\nimplementation example within [media-mgmt-cli]:\n\n```python\nfrom .config import ConfigHandler\n\n\nclass AwsStorageMgmt:\n    def __init__(self):\n        self.s3_resour = boto3.resource("s3")\n        self.s3_client = boto3.client("s3")\n        self.config = ConfigHandler(project_name="media_mgmt_cli")\n        if self.config.check_config_exists():\n            self.configs = self.config.get_configs()\n            self.bucket = self.configs.get("aws_bucket", None)\n            self.object_prefix = self.configs.get("aws_bucket_path", None)\n        else:\n            echo("config file does not exist, run `mmgmt configure`")\n\n    def upload_file(self, file_name, object_name=None):\n        """\n        ...\n        """\n        echo(\n            f"uploading: {file_name} \\nto S3 bucket: {self.configs.get(\'aws_bucket\')}/{self.configs.get(\'aws_bucket_path\')}/{file_name}"\n        )\n        ...\n```\n\n## Future Work\n\n- setup sys-config\n\n## Project Examples\n\n- [media-mgmt-cli]\n- [secret-mgmt-cli]\n\n[media-mgmt-cli]: https://github.com/william-cass-wright/media-mgmt-cli\n[secret-mgmt-cli]: https://github.com/william-cass-wright/secrets-mgmt-cli\n\n## Publishing Notes\n\n1. `make install`\n\n```Makefile\n#* Installation\n.PHONY: install\ninstall:\n    poetry lock -n && poetry export --without-hashes > requirements.txt\n    poetry install -n\n    -poetry run mypy --install-types --non-interactive ./\n```\n\n2. bump version\n\n```bash\npoetry version [major, minor, bug]\n```\n\n> only updates within pyproject.toml\n\n3. publish\n\na. trigger pre-commit\n\n```bash\ngit add .\ngit commit -m "new release"\n```\n\nb. fix issues, commit again, then tag\n\n```bash\ngit tag -a v0.2.0 -m "sys-config rewrite"\ngit push -u origin publish-branch\n```\n\nc. publish with poetry\n\n```bash\npoetry publish --dry-run --build\npoetry publish --build\n```\n\n4. test\n\n```bash\njupyter lab\npython -m pip install sys-config\n```\n\n*REPL*\n\n```python\nimport sys_config\nparser = sys_config.ConfigHandler()\nparser.__dict__\n# results\nparser.__dir__()\n# results\n```\n\n```js\n{\'project_name\': \'tmp\',\n \'home_path\': PosixPath(\'/Users/willcasswrig\'),\n \'config_path\': PosixPath(\'/Users/willcasswrig/.config/tmp\'),\n \'config_file_path\': PosixPath(\'/Users/willcasswrig/.config/tmp/config\'),\n \'verbose\': False,\n \'parser\': <configparser.ConfigParser at 0x7f8c224ec430>}\n\n\n[\'project_name\',\n \'home_path\',\n \'config_path\',\n \'config_file_path\',\n \'verbose\',\n \'parser\',\n \'__module__\',\n \'__init__\',\n \'crud_create\',\n \'create_config_file\',\n \'crud_update\',\n \'update_parser\',\n \'crud_delete_file\',\n \'crud_read\',\n \'read_dict\',\n \'get_config_exists\',\n \'get_parser_sections\',\n \'write_config_file\',\n \'set_config_path\',\n \'reset_config_path\',\n \'__dict__\',\n \'__weakref__\',\n \'__doc__\',\n \'__new__\',\n \'__repr__\',\n \'__hash__\',\n \'__str__\',\n \'__getattribute__\',\n \'__setattr__\',\n \'__delattr__\',\n \'__lt__\',\n \'__le__\',\n \'__eq__\',\n \'__ne__\',\n \'__gt__\',\n \'__ge__\',\n \'__reduce_ex__\',\n \'__reduce__\',\n \'__subclasshook__\',\n \'__init_subclass__\',\n \'__format__\',\n \'__sizeof__\',\n \'__dir__\',\n \'__class__\']\n```\n\n*errors*\n\n`parser.crud_read()`\n\n```python\n     82 def crud_read(self):\n---> 83     self.read_dict(self.__dict__, self.__class__.__name__)\n```\n\n> TypeError: Object of type PosixPath is not JSON serializable\n\n`parser.crud_create()`\n\n```\nSignature: parser.crud_create()\nDocstring: <no docstring>\nFile:      ~/miniconda/envs/jl2/lib/python3.10/site-packages/sys_config/main.py\nType:      method\n```\n\n> add docstring\n',
    'author': 'sys-config',
    'author_email': 'hello@sys-config.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/sys_config/sys-config',
    'packages': packages,
    'package_data': package_data,
    'python_requires': '>=3.9,<4.0',
}


setup(**setup_kwargs)
